#!/bin/bash

function assert
{
  if [ $? != 0 ]
  then
    echo "Error during installation of $1"
    exit 1
  fi
}

function InstallStackStorm
{
  /opt/stackstorm/installer/bash/DontRunDirectly.sh --version=$VERSION --user=$ACTIONFLOW_USER --password=$ACTIONFLOW_PASSWORD
  assert "StackStorm"
}

function InstallRPMs
{
  yum -y install gcc libffi-devel python-devel openssl-devel policycoreutils-python java-1.7.0-openjdk nc
  assert "RPMs"
}

function EncryptDB
{
  mkdir -p /etc/st2/keys
  st2-generate-symmetric-crypto-key --key-path /etc/st2/keys/datastore_key.json
  usermod -a -G st2 st2
  chown -R st2:st2 /etc/st2/keys
  chmod o-r /etc/st2/keys
  chmod o-r /etc/st2/keys/datastore_key.json
  cat << EOF >> /etc/st2/st2.conf

[keyvalue]
encryption_key_path = /etc/st2/keys/datastore_key.json
EOF
  st2ctl restart
}

function SetSt2Keys
{
  st2 key set st2_user $ACTIONFLOW_USER
  st2 key set st2_password $ACTIONFLOW_PASSWORD --encrypt
  st2 key set st2_hostname $ST2_HOSTNAME
  st2 key set rabbitmq_host $EVENTQ_HOST
  st2 key set ws_queue $WORKFLOW_QUEUE
  st2 key set actions_queue $ACTION_QUEUE
  st2 key set rabbitmq_user $AMQP_USER
  st2 key set rabbitmq_password $AMQP_PASSWORD --encrypt
}

function SetEnvironmentVariable
{
  echo 'export ST2_AUTH_TOKEN=$(st2 auth '$ACTIONFLOW_USER' -p '$ACTIONFLOW_PASSWORD' -t)' > /etc/profile.d/global.sh
  assert "set global.sh"
  export ST2_AUTH_TOKEN=$(st2 auth $ACTIONFLOW_USER -p $ACTIONFLOW_PASSWORD -t)
  assert "export ST2_AUTH_TOKEN"
}

function FinishInstaller
{
  #
  # change permissions
  #
  chown -R root:st2packs /opt/stackstorm/packs
  chown -R root:st2packs /opt/stackstorm/configs/*
  chmod -R 775 /opt/stackstorm/packs
  chmod 664 /opt/stackstorm/configs/*

  #
  # reload
  #
  st2ctl reload --register-actions
  st2ctl reload --register-rules
  st2ctl reload --register-configs
  st2ctl reload --register-all
  st2ctl restart-component st2sensorcontainer

  #
  # enable st2 when SELinux enforce
  #
  setsebool -P httpd_can_network_connect 1

  #
  # uncompress zookeeper tar ball
  #
  cd /opt
  tar xvfz zookeeper-3.4.9.tar.gz

  #
  # copy zookeeper conf file
  #
  cp -f /opt/zookeeper-3.4.9/conf/zoo_sample.cfg /opt/zookeeper-3.4.9/conf/zoo.cfg

  #
  # replace first line of zookeeper shell script
  #
  sed -i "s|#!/usr/bin/env bash|#!/bin/bash|" /opt/zookeeper-3.4.9/bin/zkServer.sh

  #
  # change protections in zookeeper
  #
  chmod -R 750 /opt/zookeeper-3.4.9

  #
  # enable zookeper service
  #
  systemctl daemon-reload
  systemctl enable zookeeper.service
  systemctl start zookeeper.service

  #
  # run nc command
  #
  echo "ruok" | nc localhost 2181  ; echo ''

  #
  # create zookeeper response file
  #
  mkdir /opt/zookeeper-3.4.9/tmp
  echo "addauth digest $ZOOKEEPER_USER:$ZOOKEEPER_PASSWORD" > /opt/zookeeper-3.4.9/tmp/input.txt
  echo "quit" >> /opt/zookeeper-3.4.9/tmp/input.txt

  #
  # set zookeeper userid and password
  #
  /opt/zookeeper-3.4.9/bin/zkCli.sh -server 127.0.0.1:2181 < /opt/zookeeper-3.4.9/tmp/input.txt

  #
  # add coordination line to st2.conf
  #
  echo " " >> /etc/st2/st2.conf
  echo "[coordination]" >> /etc/st2/st2.conf
  echo "url = kazoo://$ZOOKEEPER_USER:$ZOOKEEPER_PASSWORD@localhost:2181" >> /etc/st2/st2.conf

  #
  # install kazoo and restart StackStorm
  #
  source /opt/stackstorm/st2/bin/activate
  pip install kazoo
  st2ctl restart

  #
  # delete site-options.conf
  #
  rm -f /opt/stackstorm/installer/site-options.conf

  #
  # install action designer
  #
#  yum -y install CN-actiondesigner
}
