#!/bin/bash

source site-options.conf
source ActionFlow/ActionFlow.sh
source mongodb/mongodb.sh
source rabbitmq/rabbitmq.sh
source postgres/postgres.sh
source zookeeper/zookeeper.sh
source stackstorm/stackstorm.sh

#
# change userid and password for actionflow
#
if [ -n "$ACTIONFLOW_USER" ] && [ -n "$ACTIONFLOW_PASSWORD" ]
then
  ActionFlowCreateUser
  ActionFlowDeletePreviousUser
  ActionFlowUpdateKeys
fi

#
# create userid and password for mongodb
#
if [ -n "$MONGODB_USER" ] && [ -n "$MONGODB_PASSWORD" ]
then
  MongodbCreateJsonFile
  MongodbCreateUser
  MongodbEnableSecurity
  MongodbAppendToSt2Conf
  MongodbRestart
fi

#
# create userid and password for rabbitmq
#
if [ -n "$RABBITMQ_USER" ] && [ -n "$RABBITMQ_PASSWORD" ]
then
  RabbitmqCreateUser
  RabbitmqUpdateSt2Conf
  RabbitmqUpdateMistralConf
  RabbitmqDeleteGuest
  RabbitmqRestart
fi

#
# create userid and password for postgres
#
if [ -n "$POSTGRES_USER" ] && [ -n "$POSTGRES_PASSWORD" ]
then
  PostgresCreateUser
  PostgresRunCreateUser
  PostgresReassign
  PostgresRunReassign
  PostgresUpdateMistralConf
  PostgresDeleteMistral
  PostgresRestart
fi

#
# create userid and password for zookeeper
#
if [ -n "$ZOOKEEPER_USER" ] && [ -n "$ZOOKEEPER_PASSWORD" ]
then
  ZookeeperCreateUser
  ZookeeperUpdateSt2Conf
  ZookeeperRestart
fi

#
# create userid and password for stackstorm
#
if [ -n "$STACKSTORM_USER" ] && [ -n "$STACKSTORM_PASSWORD" ]
then
  StackStormCreateUser
  StackStormUpdateSt2Conf
  StackStormRestart
fi

#
# restore site-options.conf
#
rm -f site-options.conf

cat <<EOF > site-options.conf
#!/bin/bash

#
# both user and password need to have data in order to be changed
#

ACTIONFLOW_USER=
ACTIONFLOW_PASSWORD=
MONGODB_USER=
MONGODB_PASSWORD=
RABBITMQ_USER=
RABBITMQ_PASSWORD=
POSTGRES_USER=
POSTGRES_PASSWORD=
ZOOKEEPER_USER=
ZOOKEEPER_PASSWORD=
ST2_INTERNAL_USER=
ST2_INTERNAL_PASSWORD=
EOF
